==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/dlight.remote.impl/src/org/netbeans/modules/remote/impl/fs/RemoteFileSystemManager.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Sun Microsystems, Inc.
 */

package org.netbeans.modules.remote.impl.fs;

import java.io.IOException;
import java.lang.ref.SoftReference;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
import org.openide.filesystems.FileChangeListener;
import org.openide.util.Exceptions;

/**
 * Manages instances of the RemoteFileSystem class
 *
 * TODO: release instances when they are not used
 *
 * @author Vladimir Kvashin
 */
public class RemoteFileSystemManager {
    
    private static RemoteFileSystemManager INSTANCE = new RemoteFileSystemManager();

    private final Object lock = new Object();
    
    private Map<ExecutionEnvironment, SoftReference<RemoteFileSystem>> fileSystems =
            new HashMap<ExecutionEnvironment, SoftReference<RemoteFileSystem>>();

    private final List<FileChangeListener> globalListsners = new ArrayList<FileChangeListener>();

    public static RemoteFileSystemManager getInstance() {
        return INSTANCE;
    }

    /*package*/ void resetFileSystem(ExecutionEnvironment execEnv) {
        synchronized(lock) {
            SoftReference<RemoteFileSystem> ref = fileSystems.remove(execEnv);
            if (ref != null) {
                RemoteFileSystem fs = ref.get();
                if (fs != null) {
                    fs.dispose();
                }
            }
        }
    }

    public RemoteFileSystem getFileSystem(ExecutionEnvironment execEnv) {
        synchronized(lock) {
            SoftReference<RemoteFileSystem> ref = fileSystems.get(execEnv);
            RemoteFileSystem result = (ref == null) ? null : ref.get();
            if (result == null) {
                try {
                    result = new RemoteFileSystem(execEnv);
                    fileSystems.put(execEnv, new SoftReference<RemoteFileSystem>(result));
                    for (FileChangeListener listener : globalListsners) {
                        result.addFileChangeListener(listener);
                    }
                } catch (IOException ioe) {
                    Exceptions.printStackTrace(ioe);
                }
            }
            return result;
        }
    }

    public void addFileChangeListener(FileChangeListener listener) {
        synchronized(lock) {
            globalListsners.add(listener);
            for (SoftReference<RemoteFileSystem> ref : fileSystems.values()) {
                RemoteFileSystem fs = ref.get();
                if (fs != null) {
                    fs.addFileChangeListener(listener);
                }
            }
        }
    }
    
    public void removeFileChangeListener(FileChangeListener listener) {
        synchronized(lock) {
            globalListsners.add(listener);
            for (SoftReference<RemoteFileSystem> ref : fileSystems.values()) {
                RemoteFileSystem fs = ref.get();
                if (fs != null) {
                    fs.removeFileChangeListener(listener);
                }
            }
        }
    }
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/dlight.remote.impl/src/org/netbeans/modules/remote/impl/fs/RemoteFileSystemManager.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Sun Microsystems, Inc.
 */

package org.netbeans.modules.remote.impl.fs;

import java.io.IOException;
import java.lang.ref.SoftReference;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.netbeans.modules.nativeexecution.api.ExecutionEnvironment;
import org.openide.filesystems.FileChangeListener;
import org.openide.util.Exceptions;

/**
 * Manages instances of the RemoteFileSystem class
 *
 * TODO: release instances when they are not used
 *
 * @author Vladimir Kvashin
 */
public class RemoteFileSystemManager {
    
    private static final RemoteFileSystemManager INSTANCE = new RemoteFileSystemManager();

    private final Object lock = new Object();
    
    private final Map<ExecutionEnvironment, SoftReference<RemoteFileSystem>> fileSystems =
            new HashMap<>();

    private final List<FileChangeListener> globalListsners = new ArrayList<>();

    public static RemoteFileSystemManager getInstance() {
        return INSTANCE;
    }

    public void resetFileSystem(ExecutionEnvironment execEnv, boolean clearCache) {
        synchronized(lock) {
            SoftReference<RemoteFileSystem> ref = fileSystems.remove(execEnv);
            if (ref != null) {
                RemoteFileSystem fs = ref.get();
                if (fs != null) {
                    fs.dispose();
                }
                if (clearCache) {
                    RemoteFileSystemUtils.deleteRecursively(fs.getCache());
                }
            }
        }
    }

    public RemoteFileSystem getFileSystem(ExecutionEnvironment execEnv) {
        synchronized(lock) {
            SoftReference<RemoteFileSystem> ref = fileSystems.get(execEnv);
            RemoteFileSystem result = (ref == null) ? null : ref.get();
            if (result == null) {
                try {
                    result = new RemoteFileSystem(execEnv);
                    fileSystems.put(execEnv, new SoftReference<>(result));
                    for (FileChangeListener listener : globalListsners) {
                        result.addFileChangeListener(listener);
                    }
                } catch (IOException ioe) {
                    Exceptions.printStackTrace(ioe);
                }
            }
            return result;
        }
    }

    public void addFileChangeListener(FileChangeListener listener) {
        synchronized(lock) {
            globalListsners.add(listener);
            for (SoftReference<RemoteFileSystem> ref : fileSystems.values()) {
                RemoteFileSystem fs = ref.get();
                if (fs != null) {
                    fs.addFileChangeListener(listener);
                }
            }
        }
    }
    
    public void removeFileChangeListener(FileChangeListener listener) {
        synchronized(lock) {
            globalListsners.add(listener);
            for (SoftReference<RemoteFileSystem> ref : fileSystems.values()) {
                RemoteFileSystem fs = ref.get();
                if (fs != null) {
                    fs.removeFileChangeListener(listener);
                }
            }
        }
    }

    public Collection<RemoteFileSystem> getAllFileSystems(){
        Collection<RemoteFileSystem> res = new ArrayList<>();
        synchronized(lock) {
            for (SoftReference<RemoteFileSystem> ref : fileSystems.values()) {
                RemoteFileSystem fs = ref.get();
                if (fs != null) {
                    res.add(fs);
                }
            }
        }
        return res;
    }
}
